==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2302_169.zip: ronportal/ronportal/pokladnikniha/pokladniknihautils.php <==
<?php
/**
 * UTF-8
 * Created by PhpStorm.
 * User: pavel.rudol
 * Date: 8.6.2016
 * Time: 12:46
 */

namespace RonPortal\PokladniKniha;

use Ron\Controls\ComboBox;
use Ron\Controls\ICreateItem;
use Ron\Controls\Option;
use Ron\DB\Database;
use Ron\DB\DBException;
use Ron\DB\DBUtils;
use Ron\MessageManager;
use Ron\TextManager;
use RonPortal\Dokumenty\DokumentUploadForm;
use RonPortal\Dokumenty\DokumentyBrowser;
use RonPortal\Prava;
use RonPortal\RonPortalSettings;
use Ron\StringUtils;
use RonPortal\Security;
use function Ron\ronText;

class RadekPokladniKnihyCombo extends ComboBox implements ICreateItem
{
    /** @var Database */
    public $database;

    /**
     * RadekUctovaniSCCombo constructor.
     * @param Database $database
     */
    public function __construct(Database $database)
    {
        parent::__construct('CisloRadku');
        $this->database = $database;
    }


    public function createItem($row)
    {
        if (!$row) {
            return new Option('', ' ');
        }

        $key = $row[0]; // cislo radku
        $caption = DBUtils::getFormatedValue($this ->database, 'finedate', $row[1]) . ' ' . TextManager::_("db_typpolozkypokladniknihy_popis_$row[6]", $row[2]) . ' - ' . abs($row[3]) . ' ' . $row[4]; // datum  typ pohybu - castka mena
        if ($row[5]) $caption .= ' (' . $row[5]. ')'; // popis

        return new Option($key, $caption);
    }
}

class NovyDokumentPokladniKnihyForm extends DokumentUploadForm
{
    public $idPokladniKnihy;

    function __construct($database, $idZaznamu, $idPP)
    {
        parent::__construct($database, '?menuid=pokladnikniha&action=dokumentupload');

        $this->typDokumentu = RonPortalSettings::getIntValue('poklk_typ_dokumentu');
//        $this->target = null;

        $this->idPokladniKnihy = $idZaznamu;

        $this->hiddenFields = [
            'dokumentpokladniknihy' => '1',
            'id' => $idZaznamu,
            'idosoby' => $idPP,
        ];

        $this->redirectUrl = "?menuid=pokladnikniha&action=zaznam&record=" . $idZaznamu;

        $this->sqlPripojeniStarsiho =
            'SELECT Dokument.Id, Dokument.Popis, Dokument.Datum ' .
            '  FROM Dokument JOIN DokumentPokladniKnihy ON DokumentPokladniKnihy.Id = Dokument.Id ' .
            '   JOIN PokladniKniha ON PokladniKniha.ID = DokumentPokladniKnihy.IDPokladniKnihy ' .
            '   JOIN PracovniPomer ON PracovniPomer.RC = PokladniKniha.RC AND PracovniPomer.OsobniCislo = PokladniKniha.OsobniCislo AND PracovniPomer.DatumNastupu = PokladniKniha.DatumNastupu' .
            ' WHERE PracovniPomer.ID = ' . (int)$idPP .
            '   AND NOT EXISTS (' .
            '        SELECT * FROM DokumentPokladniKnihy DPK2' .
            '         WHERE DPK2.Id = Dokument.Id ' .
            '           AND DPK2.IDPokladniKnihy = ' . $idZaznamu .
            '       )' .
            ' ORDER BY Dokument.Datum DESC ';
    }

    /**
     * @throws DBException
     */
    public function dalsiRadkyKDokumentu()
    {
        echo '<div class="form-gap"></div>';

        // zobrazi vyber radku, ke kteremu se ma dokument pripojit
        echo '<div class="row" id="novydokument_radekpoklkrow">';

        echo '<div class="col col-12 col-sm-4 caption">' . ronText('Pripojit_dokument_k_radku_poklK') . '</div>';
        echo '<div class="col col-12 col-sm-8">';
        $combo = new RadekPokladniKnihyCombo($this ->database);

        $params = $this ->database ->createParameters();
        $sql =
            'SELECT RadekPokladniKnihy.CisloRadku, RadekPokladniKnihy.DatumPohybu, TypPolozkyPokladniKnihy.Popis, RadekPokladniKnihy.Castka, PokladniKniha.Mena, RadekPokladniKnihy.Popis, TypPolozkyPokladniKnihy.Kod' .
            '  FROM RadekPokladniKnihy JOIN TypPolozkyPokladniKnihy ON TypPolozkyPokladniKnihy.Kod = RadekPokladniKnihy.TypPolozky' .
            '  JOIN PokladniKniha ON PokladniKniha.ID = RadekPokladniKnihy.IDPokladniKnihy ' .
            ' WHERE RadekPokladniKnihy.IDPokladniKnihy = ' . $params ->addParameter((int)$this ->idPokladniKnihy) .
            ' ORDER BY DatumPohybu';

        $combo ->emptyRow = ' ';
        $combo ->dataTypeComparison = false;
        $combo ->htmlParams['id'] = 'Cislo_Radku_Pokladni_Knihy';
        $combo ->className = 'form-input documentUploadInput';
        $combo ->loadData($this ->database, $sql, null, $params);

        $combo ->render();
        echo '</div>';

        echo '</div>'; // row
    }


}

class DokumentyPokladniKnihyBrowser extends DokumentyBrowser
{
    private $idZaznamuPoklK;

    function __construct($database, $idZaznamuPoklK)
    {
        parent::__construct($database, "?menuid=pokladnikniha&action=dokumentdownload&id=$idZaznamuPoklK" . Security::csrfUrlParameter(), 1,
            "?menuid=pokladnikniha&action=dokumentdelete&id=$idZaznamuPoklK" . Security::csrfUrlParameter());

        $this->showMessages = false;

        $this->idZaznamuPoklK = $idZaznamuPoklK;

        $this->sqlFromPart = 'Dokument, TypDokumentu, DokumentPokladniKnihy';
        $this->sqlWherePart =
            'Dokument.Id = DokumentPokladniKnihy.Id ' .
            ' AND TypDokumentu.Kod = Dokument.Typ ' .
            " AND DokumentPokladniKnihy.IDPokladniKnihy = " . (int)$this->idZaznamuPoklK;
    }
}

class TypPolozkyPokladniKnihy
{
    public $kod;
    public $povolitCastkaBezDPH;
    public $povolitCastkaDPH;

    /**
     * TypPolozkyPokladniKnihy constructor.
     * @param string $kod
     * @param bool $povolitCastkaBezDPH
     * @param bool $povolitCastkaDPH
     */
    public function __construct($kod, $povolitCastkaBezDPH, $povolitCastkaDPH)
    {
        $this->kod = $kod;
        $this->povolitCastkaBezDPH = (bool)$povolitCastkaBezDPH;
        $this->povolitCastkaDPH = (bool)$povolitCastkaDPH;
    }

    /** Vraci true pokud lze pro typ polozky pokladni knihy zobrazit castku bez DPH.
     * @return bool
     */
    public function lzeZobrazitCastkuBezDPH()
    {
        return $this->povolitCastkaBezDPH;
    }

    /** Vraci true pokud lze pro typ polozky pokladni knihy zobrazit castku DPH.
     * @return bool
     */
    public function lzeZobrazitCastkuDPH()
    {
        return $this->povolitCastkaDPH;
    }
}

class SeznamPolozekPokladniKnihy
{
    public $cislo;
    /** @var string[] seznam typu polozek */
    public $seznamTypuSQL;
    /** @var  TypPolozkyPokladniKnihy[] */
    public $seznamTypu;

    public $jsonObject;

    /** 
     * @param int $cislo
     * @param string[] $seznamTypuSQL
     * @param TypPolozkyPokladniKnihy[] $seznamTypu
     * @param array $json
     */
    public function __construct($cislo, $seznamTypuSQL, $seznamTypu, $json)
    {
        $this->cislo = $cislo;
        $this->seznamTypuSQL = $seznamTypuSQL;
        $this->seznamTypu = $seznamTypu;
        $this->jsonObject = $json;
    }

    /** Vraci true, pokud lze pro nekterou z typu polozek zobrazit castku bez DPH.
     * @return bool
     */
    public function lzeZobrazitCastkuBezDPH()
    {
        foreach ($this->seznamTypu as $typPolozkyPokladniKnihy) {
            if ($typPolozkyPokladniKnihy->lzeZobrazitCastkuBezDPH()) {
                return true;
            }
        }
        return false;
    }

    /** Vraci true, pokud lze pro nekterou z typu polozek zobrazit castku DPH.
     * @return bool
     */
    public function lzeZobrazitCastkuDPH()
    {
        foreach ($this->seznamTypu as $typPolozkyPokladniKnihy) {
            if ($typPolozkyPokladniKnihy->lzeZobrazitCastkuDPH()) {
                return true;
            }
        }
        return false;
    }

    /** Vraci true pokud lze zobrazit castku. Plati pro tyto kombinace:
     * <ul>
     *  <li>Lze zobrazit castku bez DPH, ale nejde zobrazit castku DPH.</li>
     *  <li>Nelze zobrazit castku bez DPH, ale lze zobrazit castku DPH.</li>
     *  <li>Nelze zobrazit castku bez DPH ani castku DPH.</li>
     * </ul>
     * @return bool
     */
    public function lzeZobrazitCastku()
    {
        foreach ($this->seznamTypu as $typPolozkyPokladniKnihy) {
            if ($typPolozkyPokladniKnihy->lzeZobrazitCastkuBezDPH() && !$typPolozkyPokladniKnihy->lzeZobrazitCastkuDPH()) {
                return true;
            }
            if (!$typPolozkyPokladniKnihy->lzeZobrazitCastkuBezDPH() && $typPolozkyPokladniKnihy->lzeZobrazitCastkuDPH()) {
                return true;
            }
            if (!$typPolozkyPokladniKnihy->lzeZobrazitCastkuBezDPH() && !$typPolozkyPokladniKnihy->lzeZobrazitCastkuDPH()) {
                return true;
            }
        }
        return false;
    }
    
    public function jePravoNaBrowser()
    {
        foreach ($this->seznamTypuSQL as $typ) {
            $prava = Prava::vratPrava('pkniha_prohl', 'pkniha_prohl_' . $typ);
            if ($prava->jsouNejakePrava())
                return true;
            $prava = Prava::vratPrava('pkniha_vloz', 'pkniha_vloz_' . $typ);
            if ($prava->jsouNejakePrava())
                return true;
            $prava = Prava::vratPrava('pkniha_schval1', 'pkniha_schval1_' . $typ);
            if ($prava->jsouNejakePrava())
                return true;
            $prava = Prava::vratPrava('pkniha_schval2', 'pkniha_schval2_' . $typ);
            if ($prava->jsouNejakePrava())
                return true;
            $prava = Prava::vratPrava('pkniha_schval3', 'pkniha_schval3_' . $typ);
            if ($prava->jsouNejakePrava())
                return true;
            $prava = Prava::vratPrava('pkniha_schval4', 'pkniha_schval4_' . $typ);
            if ($prava->jsouNejakePrava())
                return true;
        }
        
        return false;
    }

    /** Vrati vybrany typ polozky pokladni knihy.
     * @param string $kodTypu kod typu polozky pokladni knihy
     * @return TypPolozkyPokladniKnihy
     */
    public function vratTypPolozky($kodTypu)
    {
        return $this->seznamTypu[$kodTypu] ?? null;
    }

    /** Nacte a vrati z databaze seznam typu polozek pokladni knihy pro zvoleny browser.
     * @param Database $database
     * @param int $cisloBrowseru
     * @return SeznamPolozekPokladniKnihy
     * @throws DBException
     */
    public static function vratBrowser($database, $cisloBrowseru)
    {
        $params = $database->createParameters();

        //pro číslo browseru 1 se vyhledávají i typy položek, které číslo browseru nemají zadané
        $sql =
            "SELECT Kod, PovolitCastkaBezDPH, PovolitCastkaDPH, RonPortalBrowser 
              FROM TypPolozkyPokladniKnihy
              WHERE (RonPortalBrowser = " . ($cisloBrowseru == 1 ? ($params->addParameter((int)$cisloBrowseru) . " OR RonPortalBrowser IS NULL") : $params->addParameter((int)$cisloBrowseru))  . ")
              ORDER BY RonPortalBrowser";

        $cursor = $database->getSqlResult($sql, $params);

        MessageManager::addDebugLog($sql);

        $typy = [];
        $polozky = [];
        $jsonObject = [];
        $jsonObject['items'] = [];

        while ($row = $cursor->fetch()) {
            $polozka = new TypPolozkyPokladniKnihy($row[0], $row[1], $row[2]);
            $polozky[$row[0]] = $polozka;
            $typy[] = $row[0];

            $jsonObject['items'][] = [
                'typ_polozky' => StringUtils::jsonText($row[0]),
                'povolit_castka_bez_dph' => $row[1] ? 1 : 0,
                'povolit_castka_dph' => $row[2] ? 1 : 0,
                'povolit_castka' => (!($row[1] && $row[2])) ? 1 : 0,

            ];

            $cisloBrowseru = $row[3];
        }

        return new SeznamPolozekPokladniKnihy((($cisloBrowseru != 0) ? $cisloBrowseru : 1), $typy, $polozky, $jsonObject);
    }

    /** Nacte a vrati z databaze seznam typu polozek pokladni knihy pro zvoleny browser.
     * @param Database $database
     * @param $id
     * @return SeznamPolozekPokladniKnihy
     * @throws DBException
     */
    public static function vratBrowserDleID($database, $id)
    {
        //pro číslo browseru 1 se vyhledávají i typy položek, které číslo browseru nemají zadané
        $params = $database->createParameters();
        $sql =
            "SELECT Kod, PovolitCastkaBezDPH, PovolitCastkaDPH, RonPortalBrowser 
              FROM TypPolozkyPokladniKnihy
              WHERE COALESCE(RonPortalBrowser, 1) = (SELECT COALESCE(TypPolozkyPokladniKnihy.RonPortalBrowser,1)
                                                    FROM PokladniKniha JOIN TypPolozkyPokladniKnihy ON TypPolozkyPokladniKnihy.Kod = PokladniKniha.TypPolozky
                                                    WHERE ID = " . $params->addParameter($id) . ") 
              ORDER BY RonPortalBrowser";

        $cursor = $database->getSqlResult($sql, $params);

        MessageManager::addDebugLog($sql);

        $typy = [];
        $polozky = [];
        $jsonObject = [];
        $jsonObject['items'] = [];

        while ($row = $cursor->fetch()) {
            $polozka = new TypPolozkyPokladniKnihy($row[0], $row[1], $row[2]);
            $polozky[$row[0]] = $polozka;
            $typy[] = $row[0];

            $jsonObject['items'][] = [
                'typ_polozky' => StringUtils::jsonText($row[0]),
                'povolit_castka_bez_dph' => $row[1] ? 1 : 0,
                'povolit_castka_dph' => $row[2] ? 1 : 0,
                'povolit_castka' => (!($row[1] && $row[2])) ? 1 : 0,

            ];

            $cisloBrowseru = $row[3];
        }

        return new SeznamPolozekPokladniKnihy((($cisloBrowseru != 0) ? $cisloBrowseru : 1), $typy, $polozky, $jsonObject);
    }
}

==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2311_175.zip: ronportal/ronportal/pokladnikniha/pokladniknihautils.php <==
<?php
/**
 * UTF-8
 * Created by PhpStorm.
 * User: pavel.rudol
 * Date: 8.6.2016
 * Time: 12:46
 */

namespace RonPortal\PokladniKniha;

use Ron\Controls\ComboBox;
use Ron\Controls\ICreateItem;
use Ron\Controls\Option;
use Ron\DB\Database;
use Ron\DB\DBException;
use Ron\DB\DBUtils;
use Ron\MessageManager;
use Ron\TextManager;
use RonPortal\Dokumenty\DokumentUploadForm;
use RonPortal\Dokumenty\DokumentyBrowser;
use RonPortal\Prava;
use RonPortal\RonPortalSettings;
use Ron\StringUtils;
use RonPortal\Security;
use function Ron\ronText;

class RadekPokladniKnihyCombo extends ComboBox implements ICreateItem
{
    /** @var Database */
    public $database;

    /**
     * RadekUctovaniSCCombo constructor.
     * @param Database $database
     */
    public function __construct(Database $database)
    {
        parent::__construct('CisloRadku');
        $this->database = $database;
    }


    public function createItem($row)
    {
        if (!$row) {
            return new Option('', ' ');
        }

        $key = $row[0]; // cislo radku
        $caption = DBUtils::getFormatedValue($this ->database, 'finedate', $row[1]) . ' ' . TextManager::_("db_typpolozkypokladniknihy_popis_$row[6]", $row[2]) . ' - ' . abs($row[3]) . ' ' . $row[4]; // datum  typ pohybu - castka mena
        if ($row[5]) $caption .= ' (' . $row[5]. ')'; // popis

        return new Option($key, $caption);
    }
}

class NovyDokumentPokladniKnihyForm extends DokumentUploadForm
{
    public $idPokladniKnihy;

    function __construct($database, $idZaznamu, $idPP)
    {
        parent::__construct($database, '?menuid=pokladnikniha&action=dokumentupload');

        $this->typDokumentu = RonPortalSettings::getIntValue('poklk_typ_dokumentu');
//        $this->target = null;

        $this->idPokladniKnihy = $idZaznamu;

        $this->hiddenFields = [
            'dokumentpokladniknihy' => '1',
            'id' => $idZaznamu,
            'idosoby' => $idPP,
        ];

        $this->redirectUrl = "?menuid=pokladnikniha&action=zaznam&record=" . $idZaznamu;

        $this->sqlPripojeniStarsiho =
            'SELECT Dokument.Id, Dokument.Popis, Dokument.Datum ' .
            '  FROM Dokument JOIN DokumentPokladniKnihy ON DokumentPokladniKnihy.Id = Dokument.Id ' .
            '   JOIN PokladniKniha ON PokladniKniha.ID = DokumentPokladniKnihy.IDPokladniKnihy ' .
            '   JOIN PracovniPomer ON PracovniPomer.RC = PokladniKniha.RC AND PracovniPomer.OsobniCislo = PokladniKniha.OsobniCislo AND PracovniPomer.DatumNastupu = PokladniKniha.DatumNastupu' .
            ' WHERE PracovniPomer.ID = ' . (int)$idPP .
            '   AND NOT EXISTS (' .
            '        SELECT * FROM DokumentPokladniKnihy DPK2' .
            '         WHERE DPK2.Id = Dokument.Id ' .
            '           AND DPK2.IDPokladniKnihy = ' . $idZaznamu .
            '       )' .
            ' ORDER BY Dokument.Datum DESC ';
    }

    /**
     * @throws DBException
     */
    public function dalsiRadkyKDokumentu()
    {
        echo '<div class="form-gap"></div>';

        // zobrazi vyber radku, ke kteremu se ma dokument pripojit
        echo '<div class="row" id="novydokument_radekpoklkrow">';

        echo '<div class="col col-12 col-sm-4 caption">' . ronText('Pripojit_dokument_k_radku_poklK') . '</div>';
        echo '<div class="col col-12 col-sm-8">';
        $combo = new RadekPokladniKnihyCombo($this ->database);

        $params = $this ->database ->createParameters();
        $sql =
            'SELECT RadekPokladniKnihy.CisloRadku, RadekPokladniKnihy.DatumPohybu, TypPolozkyPokladniKnihy.Popis, RadekPokladniKnihy.Castka, PokladniKniha.Mena, RadekPokladniKnihy.Popis, TypPolozkyPokladniKnihy.Kod' .
            '  FROM RadekPokladniKnihy JOIN TypPolozkyPokladniKnihy ON TypPolozkyPokladniKnihy.Kod = RadekPokladniKnihy.TypPolozky' .
            '  JOIN PokladniKniha ON PokladniKniha.ID = RadekPokladniKnihy.IDPokladniKnihy ' .
            ' WHERE RadekPokladniKnihy.IDPokladniKnihy = ' . $params ->addParameter((int)$this ->idPokladniKnihy) .
            ' ORDER BY DatumPohybu';

        $combo ->emptyRow = ' ';
        $combo ->dataTypeComparison = false;
        $combo ->htmlParams['id'] = 'Cislo_Radku_Pokladni_Knihy';
        $combo ->className = 'form-input documentUploadInput';
        $combo ->loadData($this ->database, $sql, null, $params);

        $combo ->render();
        echo '</div>';

        echo '</div>'; // row
    }


}

class DokumentyPokladniKnihyBrowser extends DokumentyBrowser
{
    private $idZaznamuPoklK;

    function __construct($database, $idZaznamuPoklK)
    {
        parent::__construct($database, "?menuid=pokladnikniha&action=dokumentdownload&id=$idZaznamuPoklK" . Security::csrfUrlParameter(), 1,
            "?menuid=pokladnikniha&action=dokumentdelete&id=$idZaznamuPoklK" . Security::csrfUrlParameter());

        $this->showMessages = false;

        $this->idZaznamuPoklK = $idZaznamuPoklK;

        $this->sqlFromPart = 'Dokument, TypDokumentu, DokumentPokladniKnihy';
        $this->sqlWherePart =
            'Dokument.Id = DokumentPokladniKnihy.Id ' .
            ' AND TypDokumentu.Kod = Dokument.Typ ' .
            " AND DokumentPokladniKnihy.IDPokladniKnihy = " . (int)$this->idZaznamuPoklK;
    }
}

class TypPolozkyPokladniKnihy
{
    public $kod;

    public $editovatRadky = true;
    public $t1Popis;
    public $t2Popis;
    public $t3Popis;
    public $t4Popis;
    public $t5Popis;
    public $i1Popis;
    public $i2Popis;
    public $i3Popis;
    public $f1Popis;
    public $f2Popis;
    public $f3Popis;

    private $povolitCastkaBezDPH;
    private $povolitCastkaDPH;

    /**
     * TypPolozkyPokladniKnihy constructor.
     * @param string $kod
     * @param bool $povolitCastkaBezDPH
     * @param bool $povolitCastkaDPH
     */
    public function __construct($kod, $povolitCastkaBezDPH, $povolitCastkaDPH)
    {
        $this->kod = $kod;
        $this->povolitCastkaBezDPH = (bool)$povolitCastkaBezDPH;
        $this->povolitCastkaDPH = (bool)$povolitCastkaDPH;
    }

    /** Vraci true pokud lze pro typ polozky pokladni knihy zobrazit castku bez DPH.
     * @return bool
     */
    public function lzeZobrazitCastkuBezDPH()
    {
        return $this->povolitCastkaBezDPH;
    }

    /** Vraci true pokud lze pro typ polozky pokladni knihy zobrazit castku DPH.
     * @return bool
     */
    public function lzeZobrazitCastkuDPH()
    {
        return $this->povolitCastkaDPH;
    }
}

class SeznamPolozekPokladniKnihy
{
    public $cislo;
    /** @var string[] seznam typu polozek */
    public $seznamTypuSQL;
    /** @var  TypPolozkyPokladniKnihy[] */
    public $seznamTypu;

    public $jsonObject;

    /** 
     * @param int $cislo
     * @param string[] $seznamTypuSQL
     * @param TypPolozkyPokladniKnihy[] $seznamTypu
     * @param array $json
     */
    public function __construct($cislo, $seznamTypuSQL, $seznamTypu, $json)
    {
        $this->cislo = $cislo;
        $this->seznamTypuSQL = $seznamTypuSQL;
        $this->seznamTypu = $seznamTypu;
        $this->jsonObject = $json;
    }

    /** Vraci true, pokud lze pro nekterou z typu polozek zobrazit castku bez DPH.
     * @return bool
     */
    public function lzeZobrazitCastkuBezDPH()
    {
        foreach ($this->seznamTypu as $typPolozkyPokladniKnihy) {
            if ($typPolozkyPokladniKnihy->lzeZobrazitCastkuBezDPH()) {
                return true;
            }
        }
        return false;
    }

    /** Vraci true, pokud lze pro nekterou z typu polozek zobrazit castku DPH.
     * @return bool
     */
    public function lzeZobrazitCastkuDPH()
    {
        foreach ($this->seznamTypu as $typPolozkyPokladniKnihy) {
            if ($typPolozkyPokladniKnihy->lzeZobrazitCastkuDPH()) {
                return true;
            }
        }
        return false;
    }

    /** Vraci true pokud lze zobrazit castku. Plati pro tyto kombinace:
     * <ul>
     *  <li>Lze zobrazit castku bez DPH, ale nejde zobrazit castku DPH.</li>
     *  <li>Nelze zobrazit castku bez DPH, ale lze zobrazit castku DPH.</li>
     *  <li>Nelze zobrazit castku bez DPH ani castku DPH.</li>
     * </ul>
     * @return bool
     */
    public function lzeZobrazitCastku()
    {
        foreach ($this->seznamTypu as $typPolozkyPokladniKnihy) {
            if ($typPolozkyPokladniKnihy->lzeZobrazitCastkuBezDPH() && !$typPolozkyPokladniKnihy->lzeZobrazitCastkuDPH()) {
                return true;
            }
            if (!$typPolozkyPokladniKnihy->lzeZobrazitCastkuBezDPH() && $typPolozkyPokladniKnihy->lzeZobrazitCastkuDPH()) {
                return true;
            }
            if (!$typPolozkyPokladniKnihy->lzeZobrazitCastkuBezDPH() && !$typPolozkyPokladniKnihy->lzeZobrazitCastkuDPH()) {
                return true;
            }
        }
        return false;
    }
    
    public function jePravoNaBrowser()
    {
        foreach ($this->seznamTypuSQL as $typ) {
            $prava = Prava::vratPrava('pkniha_prohl', 'pkniha_prohl_' . $typ);
            if ($prava->jsouNejakePrava())
                return true;
            $prava = Prava::vratPrava('pkniha_vloz', 'pkniha_vloz_' . $typ);
            if ($prava->jsouNejakePrava())
                return true;
            $prava = Prava::vratPrava('pkniha_schval1', 'pkniha_schval1_' . $typ);
            if ($prava->jsouNejakePrava())
                return true;
            $prava = Prava::vratPrava('pkniha_schval2', 'pkniha_schval2_' . $typ);
            if ($prava->jsouNejakePrava())
                return true;
            $prava = Prava::vratPrava('pkniha_schval3', 'pkniha_schval3_' . $typ);
            if ($prava->jsouNejakePrava())
                return true;
            $prava = Prava::vratPrava('pkniha_schval4', 'pkniha_schval4_' . $typ);
            if ($prava->jsouNejakePrava())
                return true;
        }
        
        return false;
    }

    /** Vrati vybrany typ polozky pokladni knihy.
     * @param string $kodTypu kod typu polozky pokladni knihy
     * @return TypPolozkyPokladniKnihy
     */
    public function vratTypPolozky($kodTypu)
    {
        return $this->seznamTypu[$kodTypu] ?? null;
    }

    private static function vratTypyPolozekBrowseru($database, $sql, $params)
    {
        $cursor = $database->getSqlResult($sql, $params);

        MessageManager::addDebugLog($sql);

        $typy = [];
        $polozky = [];
        $jsonObject = [];
        $jsonObject['items'] = [];

        while ($row = $cursor->fetch()) {
            $polozka = new TypPolozkyPokladniKnihy($row[0], $row[1], $row[2]);

            $polozka->editovatRadky = (bool)$row[4];
            $polozka->t1Popis = $row[5];
            $polozka->t2Popis = $row[6];
            $polozka->t3Popis = $row[7];
            $polozka->t4Popis = $row[8];
            $polozka->t5Popis = $row[9];
            $polozka->i1Popis = $row[10];
            $polozka->i2Popis = $row[11];
            $polozka->i3Popis = $row[12];
            $polozka->f1Popis = $row[13];
            $polozka->f2Popis = $row[14];
            $polozka->f3Popis = $row[15];

            $polozky[$row[0]] = $polozka;
            $typy[] = $row[0];

            $jsonObject['items'][] = [
                'typ_polozky' => StringUtils::jsonText($row[0]),
                'povolit_castka_bez_dph' => $row[1] ? 1 : 0,
                'povolit_castka_dph' => $row[2] ? 1 : 0,
                'povolit_castka' => (!($row[1] && $row[2])) ? 1 : 0,
                't1_popis' => StringUtils::jsonText($row[5]),
                't2_popis' => StringUtils::jsonText($row[6]),
                't3_popis' => StringUtils::jsonText($row[7]),
                't4_popis' => StringUtils::jsonText($row[8]),
                't5_popis' => StringUtils::jsonText($row[9]),
                'i1_popis' => StringUtils::jsonText($row[10]),
                'i2_popis' => StringUtils::jsonText($row[11]),
                'i3_popis' => StringUtils::jsonText($row[12]),
                'f1_popis' => StringUtils::jsonText($row[13]),
                'f2_popis' => StringUtils::jsonText($row[14]),
                'f3_popis' => StringUtils::jsonText($row[15]),

            ];

            $cisloBrowseru = $row[3];
        }

        return new SeznamPolozekPokladniKnihy((($cisloBrowseru != 0) ? $cisloBrowseru : 1), $typy, $polozky, $jsonObject);
    }

    /** Nacte a vrati z databaze seznam typu polozek pokladni knihy pro zvoleny browser.
     * @param Database $database
     * @param int $cisloBrowseru
     * @return SeznamPolozekPokladniKnihy
     * @throws DBException
     */
    public static function vratBrowser($database, $cisloBrowseru)
    {
        $params = $database->createParameters();

        //pro číslo browseru 1 se vyhledávají i typy položek, které číslo browseru nemají zadané
        $sql =
            "SELECT Kod, PovolitCastkaBezDPH, PovolitCastkaDPH, RonPortalBrowser, EditovatRadky, T1Popis, T2Popis, T3Popis, T4Popis, T5Popis, I1Popis, I2Popis, I3Popis, F1Popis, F2Popis, F3Popis 
              FROM TypPolozkyPokladniKnihy
              WHERE (RonPortalBrowser = " . ($cisloBrowseru == 1 ? ($params->addParameter((int)$cisloBrowseru) . " OR RonPortalBrowser IS NULL") : $params->addParameter((int)$cisloBrowseru))  . ")
              ORDER BY RonPortalBrowser";

        return self::vratTypyPolozekBrowseru($database, $sql, $params);
    }

    /** Nacte a vrati z databaze seznam typu polozek pokladni knihy pro zvoleny browser.
     * @param Database $database
     * @param $id
     * @return SeznamPolozekPokladniKnihy
     * @throws DBException
     */
    public static function vratBrowserDleID($database, $id)
    {
        //pro číslo browseru 1 se vyhledávají i typy položek, které číslo browseru nemají zadané
        $params = $database->createParameters();
        $sql =
            "SELECT Kod, PovolitCastkaBezDPH, PovolitCastkaDPH, RonPortalBrowser, EditovatRadky, T1Popis, T2Popis, T3Popis, T4Popis, T5Popis, I1Popis, I2Popis, I3Popis, F1Popis, F2Popis, F3Popis 
              FROM TypPolozkyPokladniKnihy
              WHERE COALESCE(RonPortalBrowser, 1) = (SELECT COALESCE(TypPolozkyPokladniKnihy.RonPortalBrowser,1)
                                                    FROM PokladniKniha JOIN TypPolozkyPokladniKnihy ON TypPolozkyPokladniKnihy.Kod = PokladniKniha.TypPolozky
                                                    WHERE ID = " . $params->addParameter($id) . ") 
              ORDER BY RonPortalBrowser";

        return self::vratTypyPolozekBrowseru($database, $sql, $params);
    }
}
